"""
Tool aliases configuration.
Maps command aliases to their actual tool module names.
"""

TOOL_ALIASES = {
    "compare": "colcompare",
    "rowcount": "dbstats",
}
